@@ -131,13 +131,13 @@ test_that("asking for the outcome when it isn't there fails", {
   example_train2 <- example_train
   example_train2$fac_1 <- NULL
 
-  expect_error(
-    forge(example_train2, x1$blueprint, outcomes = TRUE),
-    "The following required columns"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train2, x1$blueprint, outcomes = TRUE)
   )
-  expect_error(
-    forge(example_train2, x2$blueprint, outcomes = TRUE),
-    "The following required columns"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train2, x2$blueprint, outcomes = TRUE)
   )
 })
 
@@ -178,14 +178,8 @@ test_that("new_data can be a matrix", {
   x2 <- mold(fac_1 ~ num_1, example_train, blueprint = bp)
   example_train_mat <- as.matrix(example_train[, "num_1", drop = FALSE])
 
-  expect_error(
-    xx1 <- forge(example_train_mat, x1$blueprint),
-    NA
-  )
-  expect_error(
-    xx2 <- forge(example_train_mat, x2$blueprint),
-    NA
-  )
+  expect_no_error(xx1 <- forge(example_train_mat, x1$blueprint))
+  expect_no_error(xx2 <- forge(example_train_mat, x2$blueprint))
 
   sep_len <- example_train$num_1
 
@@ -204,13 +198,13 @@ test_that("new_data can only be a data frame / matrix", {
   x1 <- mold(fac_1 ~ num_1, example_train)
   x2 <- mold(fac_1 ~ num_1, example_train, blueprint = bp)
 
-  expect_error(
-    forge("hi", x1$blueprint),
-    "The class of `new_data`, 'character'"
+  expect_snapshot(
+    error = TRUE,
+    forge("hi", x1$blueprint)
   )
-  expect_error(
-    forge("hi", x2$blueprint),
-    "The class of `new_data`, 'character'"
+  expect_snapshot(
+    error = TRUE,
+    forge("hi", x2$blueprint)
   )
 })
 
@@ -219,22 +213,22 @@ test_that("missing predictor columns fail appropriately", {
   x1 <- mold(fac_1 ~ num_1 + num_2, example_train)
   x2 <- mold(fac_1 ~ num_1 + num_2, example_train, blueprint = bp)
 
-  expect_error(
-    forge(example_train[, 1, drop = FALSE], x1$blueprint),
-    "num_2"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 1, drop = FALSE], x1$blueprint)
   )
-  expect_error(
-    forge(example_train[, 1, drop = FALSE], x2$blueprint),
-    "num_2"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 1, drop = FALSE], x2$blueprint)
   )
 
-  expect_error(
-    forge(example_train[, 3, drop = FALSE], x1$blueprint),
-    "'num_1', 'num_2'"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 3, drop = FALSE], x1$blueprint)
   )
-  expect_error(
-    forge(example_train[, 3, drop = FALSE], x2$blueprint),
-    "'num_1', 'num_2'"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 3, drop = FALSE], x2$blueprint)
   )
 })
 
@@ -254,14 +248,8 @@ test_that("novel predictor levels are caught", {
   x2 <- mold(y ~ f, dat, blueprint = bp)
 
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 1]],
@@ -271,6 +259,14 @@ test_that("novel predictor levels are caught", {
     unname(xx2$predictors[5, 1]),
     NA_real_
   )
+
+  new_multiple <- data.frame(
+    y = 1:6,
+    f = factor(letters[1:6])
+  )
+  x3 <- mold(y ~ f, dat)
+
+  expect_snapshot(xx3 <- forge(new_multiple, x3$blueprint))
 })
 
 test_that("novel predictor levels can be ignored", {
@@ -290,14 +286,9 @@ test_that("novel predictor levels can be ignored", {
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 5]],
@@ -397,14 +388,8 @@ test_that("novel levels are handled correctly when the new column is a character
   x1 <- mold(y ~ f, dat)
   x2 <- mold(y ~ f, dat, blueprint = bp)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 1]],
@@ -482,14 +467,9 @@ test_that("novel levels are ignored correctly when the new column is a character
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 5]],
@@ -590,14 +570,8 @@ test_that("novel outcome levels are caught", {
   x1 <- mold(f ~ y, dat)
   x2 <- mold(f ~ y, dat, blueprint = bp)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint, outcomes = TRUE))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint, outcomes = TRUE))
 
   expect_equal(
     xx1$outcomes[[5, 1]],
@@ -626,14 +600,8 @@ test_that("novel outcome levels are always caught, even if `allow_novel_levels =
   x1 <- mold(f ~ y, dat, blueprint = bp1)
   x2 <- mold(f ~ y, dat, blueprint = bp2)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint, outcomes = TRUE))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint, outcomes = TRUE))
 
   expect_equal(
     xx1$outcomes[[5, 1]],
@@ -667,14 +635,9 @@ test_that("missing predictor levels are restored silently", {
   x1 <- mold(y ~ f, dat)
   x2 <- mold(y ~ f, dat, blueprint = bp)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     colnames(xx1$predictors),
@@ -685,14 +648,9 @@ test_that("missing predictor levels are restored silently", {
     c("fa", "fb", "fc", "fd")
   )
 
-  expect_warning(
-    yy1 <- forge(new2, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    yy2 <- forge(new2, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(yy1 <- forge(new2, x1$blueprint))
+  expect_snapshot(yy2 <- forge(new2, x2$blueprint))
 
   expect_equal(
     colnames(yy1$predictors),
@@ -750,12 +708,19 @@ test_that("can be both missing levels and have new levels", {
     mold(y ~ f, dat, blueprint = bp2)
   })
 
-  # Warning for the extra level
-  expect_warning(
-    xx <- forge(new, x1$blueprint),
-    "Novel levels found in column 'f': 'e'"
+  dat_2f <- data.frame(
+    y = 1:4,
+    f = factor(letters[1:4]),
+    f_2 = factor(letters[5:8])
   )
 
+  expect_snapshot(error = TRUE, {
+    mold(y ~ f + f_2, dat_2f, blueprint = bp2)
+  })
+
+  # Warning for the extra level
+  expect_snapshot(xx <- forge(new, x1$blueprint))
+
   expect_equal(
     levels(xx$predictors$f),
     levels(dat$f)
@@ -777,10 +742,8 @@ test_that("can be both missing levels and have new levels that get ignored", {
 
   x <- mold(y ~ f, dat, blueprint = blueprint)
 
-  expect_warning(
-    xx <- forge(new, x$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx <- forge(new, x$blueprint))
 
   # Order of levels comes from `new` first, then `dat`
   expect_equal(
@@ -804,10 +767,7 @@ test_that("`NA` factor data never triggers a novel level warning (#131)", {
 
   x <- mold(y ~ f, dat, blueprint = blueprint)
 
-  expect_warning(
-    xx <- forge(new, x$blueprint),
-    NA
-  )
+  expect_snapshot(xx <- forge(new, x$blueprint))
 
   expect_identical(
     xx$predictors$f,
@@ -822,9 +782,8 @@ test_that("new data classes are caught", {
   x <- mold(num_1 ~ fac_1, example_train, blueprint = default_formula_blueprint(indicators = "none"))
 
   # Silently recover character -> factor
-  expect_error(
-    x_example_train2 <- forge(example_train2, x$blueprint),
-    NA
+  expect_no_error(
+    x_example_train2 <- forge(example_train2, x$blueprint)
   )
 
   expect_s3_class(
@@ -834,9 +793,8 @@ test_that("new data classes are caught", {
 
   xx <- mold(fac_1 ~ num_1, example_train)
 
-  expect_error(
-    xx_example_train2 <- forge(example_train2, xx$blueprint, outcomes = TRUE),
-    NA
+  expect_no_error(
+    xx_example_train2 <- forge(example_train2, xx$blueprint, outcomes = TRUE)
   )
 
   expect_s3_class(
@@ -853,25 +811,17 @@ test_that("new data classes can interchange integer/numeric", {
   x1 <- mold(fac_1 ~ num_1, example_train)
   x2 <- mold(fac_1 ~ num_1, example_train, blueprint = bp)
 
-  expect_error(
-    forge(example_train2, x1$blueprint),
-    NA
-  )
-  expect_error(
-    forge(example_train2, x2$blueprint),
-    NA
-  )
+  expect_no_error(forge(example_train2, x1$blueprint))
+  expect_no_error(forge(example_train2, x2$blueprint))
 
   x3 <- mold(num_1 ~ fac_1, example_train)
   x4 <- mold(num_1 ~ fac_1, example_train, blueprint = bp)
 
-  expect_error(
-    forge(example_train2, x3$blueprint, outcomes = TRUE),
-    NA
+  expect_no_error(
+    forge(example_train2, x3$blueprint, outcomes = TRUE)
   )
-  expect_error(
-    forge(example_train2, x4$blueprint, outcomes = TRUE),
-    NA
+  expect_no_error(
+    forge(example_train2, x4$blueprint, outcomes = TRUE)
   )
 })
 
